RESOURCE_MAPPING_V2 = {
    "campaigns": {
        "resource": "v2/campaigns",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns.html",
        "key": "campaigns",
        "extract_from_response": {
            "domain": "{string}",
            "id": "{int64}",
            "clientId": "{int64}",
            "state": "{int32}",
            "stateReasons": ["{int32}", ...],
        },
    },
    "campaign": {
        "resource": "v2/campaigns/{campaignId}",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id.html",
        "key": "campaign",
        "extract_from_response": {
            "domain": "{string}",
            "id": "{int64}",
            "clientId": "{int64}",
            "state": "{int32}",
            "stateReasons": ["{int32}", ...],
        },
    },
    "logins": {
        "resource": "v2/campaigns/{campaignId}/logins",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-logins.html",
        "key": "logins",
        "extract_from_response": {"logins": ["{string}", ...]},
    },
    "campaigns_by_login": {
        "resource": "v2/campaigns/by_login/{login}",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-by-login.html",
        "key": "campaigns",
        "extract_from_response": {
            "domain": "{string}",
            "id": "{int64}",
            "clientId": "{int64}",
            "state": "{int32}",
            "stateReasons": ["{int32}", ...],
        },
    },
    "settings": {
        "resource": "v2/campaigns/{campaignId}/settings",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-settings.html",
        "key": "settings",
        "extract_from_response": {
            "countryRegion": "{int64}",
            "isOnline": "{boolean}",
            "shopName": "{string}",
            "showInContext": "{boolean}",
            "showInPremium": "{boolean}",
            "showInSnippets": "{boolean}",
            "useOpenStat": "{boolean}",
            "localRegion": {
                "id": "{int64}",
                "name": "{string}",
                "type": "{enum}",
                "delivery": {
                    "schedule": {
                        "availableOnHolidays": "{boolean}",
                        "source": "{enum}",
                        "customHolidays": ["{date}", ...],
                        "customWorkingDays": ["{date}", ...],
                        "period": {"fromDate": "{date}", "toDate": "{date}"},
                        "totalHolidays": ["{date}", ...],
                        "weeklyHolidays": ["{int8}", ...],
                    }
                },
            },
        },
    },
    "region": {
        "resource": "v2/campaigns/{campaignId}/region",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-region.html",
        "key": "region",
        "extract_from_response": {
            "id": "{int64}",
            "name": "{string}",
            "type": "{enum}",
            "parent": {
                "id": "{int64}",
                "name": "{string}",
                "type": "{enum}",
                "parent": {...},
            },
        },
    },
    "feedback_updates": {
        "resource": "v2/campaigns/{campaignId}/feedback/updates",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-feedback-updates.html",
        "key": ["result", "feedbackList"],
        "extract_from_response": {
            "id": "{int64}",
            "createdAt": "{date}",
            "state": "{enum}",
            "recommend": "{boolean}",
            "resolved": "{boolean}",
            "author": {
                "name": "{string}",
                "region": {"id": "{int64}", "name": "{string}", "type": "{enum}"},
            },
            "shop": {"name": "{string}"},
            "grades": {
                "average": "{int32}",
                "agreeCount": "{int64}",
                "rejectCount": "{int64}",
                "factors": [
                    {
                        "id": "{int64}",
                        "title": "{string}",
                        "description": "{string}",
                        "value": "{int32}",
                    },
                    ...,
                ],
            },
            "pro": "{string}",
            "contra": "{string}",
            "text": "{string}",
            "order": {
                "shopOrderId": "{string}",
                "delivery": "{enum}",
            },
            "comments": [
                {
                    "id": "{int64}",
                    "createdAt": "{date}",
                    "updatedAt": "{date}",
                    "author": {"type": "{enum}", "name": "{string}"},
                    "body": "{string}",
                    "children": [
                        {
                            "id": "{int64}",
                            "parentId": "{int64}",
                            "createdAt": "{date}",
                            "updatedAt": "{date}",
                            "author": {"type": "{enum}", "name": "{string}"},
                            "body": "{string}",
                            "children": [...],
                        },
                        ...,
                    ],
                },
                ...,
            ],
        },
    },
    "offers": {
        "resource": "v2/campaigns/{campaignId}/offers",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-offers.html",
        "key": "offers",
        "extract_from_response": {
            "bid": "{double}",
            "currency": "{enum}",
            "cutPrice": "{boolean}",
            "discount": "{int32}",
            "feedId": "{int64}",
            "id": "{string}",
            "marketCategoryId": "{int32}",
            "modelId": "{int32}",
            "preDiscountPrice": "{float}",
            "price": "{float}",
            "shopCategoryId": "{string}",
            "name": "{string}",
            "url": "{string}",
        },
    },
    "all_offers": {
        "resource": "v2/campaigns/{campaignId}/offers/all",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-offers-all.html",
        "key": "offers",
        "extract_from_response": {
            "bid": "{double}",
            "blocked": "{boolean}",
            "currency": "{enum}",
            "discount": "{integer}",
            "feedId": "{integer}",
            "id": "{string}",
            "marketCategoryId": "{integer}",
            "modelId": "{integer}",
            "preDiscountPrice": "{float}",
            "price": "{float}",
            "shopCategoryId": "{string}",
            "name": "{string}",
            "url": "{string}",
        },
    },
    "feeds": {
        "resource": "v2/campaigns/{campaignId}/feeds",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-feeds.html",
        "key": "feeds",
        "extract_from_response": {
            "id": "{int64}",
            "login": "{string}",
            "name": "{string}",
            "password": "{string}",
            "uploadDate": "{date}",
            "url": "{string}",
            "content": {
                "rejectedOffersCount": "{int32}",
                "status": "{enum}",
                "totalOffersCount": "{int32}",
                "error": {"type": "{enum}"},
            },
            "download": {
                "status": "{enum}",
                "error": {
                    "httpStatusCode": "{int32}",
                    "type": "{enum}",
                    "description": "{string}",
                },
            },
            "placement": {"totalOffersCount": "{int32}"},
            "publication": {
                "status": "{enum}",
                "full": {"fileTime": "{date}", "publishedTime": "{date}"},
                "priceAndStockUpdate": {
                    "fileTime": "{date}",
                    "publishedTime": "{date}",
                },
            },
        },
    },
    "feed": {
        "resource": "v2/campaigns/{campaignId}/feeds/{feedId}",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-feeds-id.html",
        "key": "feed",
        "extract_from_response": {
            "id": "{int64}",
            "login": "{string}",
            "name": "{string}",
            "password": "{string}",
            "uploadDate": "{date}",
            "url": "{string}",
            "content": {
                "rejectedOffersCount": "{int32}",
                "status": "{enum}",
                "totalOffersCount": "{int32}",
                "error": {"type": "{enum}"},
            },
            "download": {
                "status": "{enum}",
                "error": {
                    "httpStatusCode": "{int32}",
                    "type": "{enum}",
                    "description": "{string}",
                },
            },
            "placement": {"totalOffersCount": "{int32}"},
            "publication": {
                "status": "{enum}",
                "full": {"fileTime": "{date}", "publishedTime": "{date}"},
                "priceAndStockUpdate": {
                    "fileTime": "{date}",
                    "publishedTime": "{date}",
                },
            },
        },
    },
    "feed_categories": {
        "resource": "v2/campaigns/{campaignId}/feeds/{feedId}/categories",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-feeds-id-categories.html",
        "key": "categories",
        "extract_from_response": {
            "feedId": "{int64}",
            "id": "{string}",
            "name": "{string}",
            "parentId": "{string}",
        },
    },
    "all_feeds_categories": {
        "resource": "v2/campaigns/{campaignId}/feeds/categories",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-feeds-categories.html",
        "key": "categories",
        "extract_from_response": {
            "feedId": "{int64}",
            "id": "{string}",
            "name": "{string}",
            "parentId": "{string}",
        },
    },
    "feed_index_logs": {
        "resource": "v2/campaigns/{campaignId}/feeds/{feedId}/index-logs",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-feeds-id-index-logs.html",
        "key": "result",
        "extract_from_response": {
            "feed": {
                "id": "{int64}",
            },
            "indexLogRecords": [
                {
                    "downloadTime": "{date}",
                    "fileTime": "{date}",
                    "generationId": "{int64}",
                    "indexType": "{enum}",
                    "publishedTime": "{date}",
                    "status": "{enum}",
                    "error": {
                        "httpStatusCode": "{int32}",
                        "type": "{enum}",
                        "description": "{string}",
                    },
                    "offers": {"rejectedCount": "{int32}", "totalCount": "{int32}"},
                },
                ...,
            ],
            "total": "{int32}",
        },
    },
    "feed_parameters": {
        "resource": "v2/campaigns/{campaignId}/feeds/{feedId}/params",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-feeds-id-params.html",
        "key": "parameters",
        "extract_from_response": {
            "deleted": "{boolean}",
            "name": "{enum}",
            "values": ["{int32}", ...],
        },
    },
    "feed_refresh": {
        "resource": "v2/campaigns/{campaignId}/feeds/{feedId}/refresh",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-feeds-id-refresh.html",
    },
    "hidden_offers": {
        "resource": "v2/campaigns/{campaignId}/hidden-offers",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-hidden-offers.html",
        "key": ["result", "hiddenOffers"],
        "extract_from_response": {
            "comment": "{string}",
            "feedId": "{int64}",
            "offerId": "{string}",
            "ttlInHours": "{int32}",
        },
    },
    "update_offer_prices": {
        "resource": "v2/campaigns/{campaignId}/offer-prices/updates",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-offer-prices-updates.html",
        "key": "offers",
        "extract_from_response": {
            "feed": {"id": "{int64}"},
            "id": "{string}",
            "delete": "{boolean}",
            "price": {
                "currencyId": "{enum}",
                "value": "{float}",
                "discountBase": "{float}",
            },
        },
    },
    "remove_offer_prices": {
        "resource": "v2/campaigns/{campaignId}/offer-prices/removals",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-offer-prices-removals.html",
    },
    "offer_prices": {
        "resource": "v2/campaigns/{campaignId}/offer-prices",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-offer-prices.html",
        "key": ["result", "offers"],
        "extract_from_response": {
            "feed": {"id": "{int64}"},
            "id": "{string}",
            "price": {
                "currencyId": "{enum}",
                "discountBase": "{float}",
                "value": "{float}",
            },
            "updatedAt": "{string}",
        },
    },
    "model": {
        "resource": "v2/models/{modelId}",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-models-id.html",
        "key": "models",
        "extract_from_response": {
            "id": "{int64}",
            "name": "{string}",
            "prices": {"avg": "{float}", "max": "{float}", "min": "{float}"},
        },
    },
    "models": {
        "resource": "v2/models",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-models.html",
        "key": "models",
        "extract_from_response": {
            "id": "{int64}",
            "name": "{string}",
            "prices": {"avg": "{float}", "max": "{float}", "min": "{float}"},
        },
    },
    "model_offers": {
        "resource": "v2/models/{modelId}/offers",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-models-id-offers.html",
        "extract_from_response": {
            "currency": "{enum}",
            "models": [
                {
                    "id": "{int64}",
                    "offers": [
                        {
                            "discount": "{int32}",
                            "name": "{string}",
                            "pos": "{int32}",
                            "preDiscountPrice": "{float}",
                            "price": "{float}",
                            "regionId": "{int64}",
                            "shippingCost": "{float}",
                            "shopName": "{string}",
                            "shopRating": "{int32}",
                            "inStock": "{int32}",
                        },
                        ...,
                    ],
                    "offlineOffers": "{int32}",
                    "onlineOffers": "{int32}",
                }
            ],
            "regionId": "{int64}",
        },
    },
    "models_offers": {
        "resource": "v2/models/offers",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-models-offers.html",
        "extract_from_response": {"models": ["{int64}", ...]},
    },
    "bids": {
        "resource": "v2/campaigns/{campaignId}/auction/bids",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-auction-bids.html",
        "key": "offers",
    },
    "bid_recommendations": {
        "resource": "v2/campaigns/{campaignId}/auction/recommendations/bids",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-auction-recommendations-bids.html",
        "key": "offers",
    },
    "top_market_search": {
        "resource": "v2/campaigns/{campaignId}/bids/recommended/top/market-search",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-bids-recommended-top-market-search.html",
        "key": "offers",
        "extract_from_response": {"feedId": "{int64}", "id": "{string}"},
    },
    "bids_settings": {
        "resource": "v2/campaigns/{campaignId}/bids/settings",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-bids-settings.html",
        "key": "settings",
        "extract_from_response": {
            "autobrokerEnabled": "{boolean}",
            "bidsFrom": "{enum}",
            "offerIdBy": "{enum}",
            "bookBids": {"bid": "{int64}"},
            "shopBids": {"bid": "{int64}"},
        },
    },
    "balance": {
        "resource": "v2/campaigns/{campaignId}/balance",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-balance.html",
        "key": "balance",
        "extract_from_response": {
            "balance": "{double}",
            "daysLeft": "{int32}",
            "recommendedPayment": "{double}",
        },
    },
    "invoice_pay_preview": {
        "resource": "v2/campaigns/{campaignId}/invoice/paypreview",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-invoice-paypreview.html",
        "key": "result",
        "extract_from_response": {
            "url": "{string}",
            "requestId": "{int64}",
            "parentPerson": {
                "clientId": "{int64}",
                "name": "{string}",
                "isAgency": "{boolean}",
                "agencyId": "{int64}",
            },
            "pcps": [
                {
                    "person": {
                        "personId": "{int64}",
                        "name": "{string}",
                        "legalEntity": "{boolean}",
                        "regionId": "{int32}",
                        "resident": "{boolean}",
                    },
                    "contract": {"contractId": "{int64}", "externalId": "{string}"},
                    "paysyses": [
                        {
                            "paysysId": "{int64}",
                            "cc": "{enum}",
                            "name": "{string}",
                            "paymentMethod": "{enum}",
                            "legalEntity": "{boolean}",
                            "regionId": "{int32}",
                            "resident": "{boolean}",
                            "paymentLimit": "{double}",
                        },
                        ...,
                    ],
                },
                ...,
            ],
        },
    },
    "invoice": {
        "resource": "v2/invoice",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-invoice.html",
    },
    "campaign_invoice": {
        "resource": "v2/campaigns/{campaignId}/invoices/{invoiceId}",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-invoices-id.html",
    },
    "stats": {
        "resource": "v2/campaigns/{campaignId}/stats/main",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-stats-main.html",
        "key": "mainStats",
        "extract_from_response": {
            "clicks": "{int32}",
            "date": "{date}",
            "placeGroup": "{int32}",
            "shows": "1525855",
            "spending": "{int32}",
            "clicksMobile": "{int32}",
            "showsMobile": "{string}",
            "spendingMobile": "{float}",
        },
    },
    "daily_stats": {
        "resource": "v2/campaigns/{campaignId}/stats/main-daily",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-stats-main.html#examples__main-daily",
        "key": "mainStats",
        "extract_from_response": {
            "clicks": "{int32}",
            "date": "{date}",
            "placeGroup": "{int32}",
            "shows": "1525855",
            "spending": "{int32}",
            "clicksMobile": "{int32}",
            "showsMobile": "{string}",
            "spendingMobile": "{float}",
        },
    },
    "weekly_stats": {
        "resource": "v2/campaigns/{campaignId}/stats/main-weekly",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-stats-main.html#examples__main-weekly",
        "key": "mainStats",
        "extract_from_response": {
            "clicks": "{int32}",
            "date": "{date}",
            "placeGroup": "{int32}",
            "shows": "1525855",
            "spending": "{int32}",
            "clicksMobile": "{int32}",
            "showsMobile": "{string}",
            "spendingMobile": "{float}",
        },
    },
    "monthly_stats": {
        "resource": "v2/campaigns/{campaignId}/stats/main-monthly",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-stats-main.html#examples__main-monthly",
        "key": "mainStats",
        "extract_from_response": {
            "clicks": "{int32}",
            "date": "{date}",
            "placeGroup": "{int32}",
            "shows": "1525855",
            "spending": "{int32}",
            "clicksMobile": "{int32}",
            "showsMobile": "{string}",
            "spendingMobile": "{float}",
        },
    },
    "offers_stats": {
        "resource": "v2/campaigns/{campaignId}/stats/offers",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-stats-offers.html",
        "key": ["offersStats", "offerStats"],
        "extract_from_response": {
            "clicks": "{int32}",
            "feedId": "{int64}",
            "offerId": "{string}",
            "spending": "{string}",
            "clicksMobile": "{int32}",
            "spendingMobile": "{float}",
            "offerName": "{string}",
            "url": "{string}",
        },
    },
    "geo_regions": {
        "resource": "v2/regions",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-regions.html",
        "key": "regions",
        "extract_from_response": {
            "id": "{int64}",
            "name": "{string}",
            "type": "{enum}",
            "parent": {
                "id": "{int64}",
                "name": "{string}",
                "type": "{enum}",
                "parent": {...},
            },
        },
    },
    "geo_region": {
        "resource": "v2/regions/{regionId}",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-regions-id.html",
        "key": "regions",
        "extract_from_response": {
            "id": "{int64}",
            "name": "{string}",
            "type": "{enum}",
            "parent": {
                "id": "{int64}",
                "name": "{string}",
                "type": "{enum}",
                "parent": {...},
            },
        },
    },
    "region_children": {
        "resource": "v2/regions/{regionId}/children",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-regions-id-children.html",
        "key": "regions",
        "extract_from_response": {
            "id": "{int64}",
            "name": "{string}",
            "type": "{enum}",
            "children": [{"id": "{int64}", "name": "{string}", "type": "{enum}"}, ...],
            "parent": {
                "id": "{int64}",
                "name": "{string}",
                "type": "{enum}",
            },
        },
    },
    "outlets": {
        "resource": "v2/campaigns/{campaignId}/outlets",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-outlets.html",
        "extract_from_response": {
            "name": "{string}",
            "type": "{enum}",
            "coords": "{string}",
            "isMain": "{boolean}",
            "shopOutletCode": "{string}",
            "visibility": "{enum}",
            "isBookNow": "{boolean}",
            "address": {
                "regionId": "{int64}",
                "street": "{string}",
                "number": "{string}",
                "building": "{string}",
                "estate": "{string}",
                "block": "{string}",
                "additional": "{string}",
                "km": "{integer}",
            },
            "phones": ["{string}", ...],
            "workingSchedule": {
                "workInHoliday": "{boolean}",
                "scheduleItems": [
                    {
                        "startDay": "{enum}",
                        "endDay": "{enum}",
                        "startTime": "{string}",
                        "endTime": "{string}",
                    },
                    ...,
                ],
            },
            "deliveryRules": [
                {
                    "cost": "{double}",
                    "minDeliveryDays": "{int32}",
                    "maxDeliveryDays": "{int32}",
                    "deliveryServiceId": "{int64}",
                    "orderBefore": "{int32}",
                    "priceFreePickup": "{double}",
                    "unspecifiedDeliveryInterval": "{boolean}",
                }
            ],
            "emails": ["{string}"],
        },
    },
    "outlet": {
        "resource": "v2/campaigns/{campaignId}/outlets/{outletId}",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/put-campaigns-id-outlets-id.html",
        "extract_from_response": {
            "name": "{string}",
            "type": "{enum}",
            "coords": "{string}",
            "isMain": "{boolean}",
            "shopOutletCode": "{string}",
            "visibility": "{enum}",
            "isBookNow": "{boolean}",
            "address": {
                "regionId": "{int64}",
                "street": "{string}",
                "number": "{string}",
                "building": "{string}",
                "estate": "{string}",
                "block": "{string}",
                "additional": "{string}",
                "km": "{integer}",
            },
            "phones": ["{string}", ...],
            "workingSchedule": {
                "workInHoliday": "{boolean}",
                "scheduleItems": [
                    {
                        "startDay": "{enum}",
                        "endDay": "{enum}",
                        "startTime": "{string}",
                        "endTime": "{string}",
                    },
                    ...,
                ],
            },
            "deliveryRules": [
                {
                    "cost": "{double}",
                    "minDeliveryDays": "{int32}",
                    "maxDeliveryDays": "{int32}",
                    "deliveryServiceId": "{int64}",
                    "orderBefore": "{int32}",
                    "priceFreePickup": "{double}",
                    "unspecifiedDeliveryInterval": "{boolean}",
                }
            ],
            "emails": ["{string}"],
        },
    },
    "campaign_outlets": {
        "resource": "v2/campaigns/{campaignId}/outlets",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-outlets.html",
        "key": "outlets",
        "extract_from_response": {
            "coords": "{string}",
            "id": "{int64}",
            "isMain": "{boolean}",
            "name": "{string}",
            "reason": "{string}",
            "shopOutletCode": "{string}",
            "status": "{enum}",
            "type": "{enum}",
            "visibility": "{enum}",
            "isBookNow": "{boolean}",
            "shopOutletId": "{string}",
            "workingTime": "{string}",
            "address": {
                "regionId": "{int64}",
                "street": "{string}",
                "number": "{string}",
                "building": "{string}",
                "estate": "{string}",
                "block": "{string}",
                "additional": "{string}",
                "km": "{integer}",
                "city": "{string}",
            },
            "deliveryRules": [
                {
                    "cost": "{double}",
                    "minDeliveryDays": "{int32}",
                    "maxDeliveryDays": "{int32}",
                    "deliveryServiceId": "{int64}",
                    "orderBefore": "{int32}",
                    "priceFreePickup": "{double}",
                    "unspecifiedDeliveryInterval": "{boolean}",
                    "dateSwitchHour": "{int32}",
                    "priceFrom": "{double}",
                    "priceTo": "{double}",
                    "shipperHumanReadableId": "{string}",
                    "shipperId": "{int64}",
                    "shipperName": "{string}",
                    "workInHoliday": "{boolean}",
                }
            ],
            "emails": ["{string}"],
            "phones": ["{string}", ...],
            "region": {
                "id": "{int64}",
                "name": "{string}",
                "type": "{enum}",
                "parent": {
                    "id": "{int64}",
                    "name": "{string}",
                    "type": "{enum}",
                    "parent": {...},
                },
            },
            "workingSchedule": {
                "workInHoliday": "{boolean}",
                "scheduleItems": [
                    {
                        "startDay": "{enum}",
                        "endDay": "{enum}",
                        "startTime": "{string}",
                        "endTime": "{string}",
                    },
                    ...,
                ],
            },
        },
    },
    "outlets_licenses": {
        "resource": "v2/campaigns/{campaignId}/outlets/licenses",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-outlets-licenses.html",
        "key": "licenses",
        "extract_from_response": {
            "id": "{int64}",
            "outletId": "{int64}",
            "licenseType": "{enum}",
            "number": "{string}",
            "dateOfIssue": "{date}",
            "dateOfExpiry": "{date}",
        },
    },
    "delivery_services_dictionary": {
        "resource": "v2/delivery/services",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-delivery-services.html",
        "key": ["result", "deliveryService"],
        "extract_from_response": {"id": "{int64}", "name": "{string}"},
    },
    "quality_tickets": {
        "resource": "v2/campaigns/{campaignId}/quality/tickets",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-quality-tickets.html",
        "key": ["result", "tickets"],
        "extract_from_response": {
            "checkMethod": "{int8}",
            "errorCode": "{int32}",
            "errorFoundTime": "{date}",
            "errorText": "{string}",
            "feedTime": "{date}",
            "offerURL": "{string}",
            "orderId": "{string}",
            "status": "{int8}",
            "ticketId": "{int64}",
        },
    },
    "quality_ticket": {
        "resource": "v2/campaigns/{campaignId}/quality/tickets/{ticketId}",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-quality-tickets-id.html",
        "key": ["result", "tickets"],
        "extract_from_response": {
            "checkMethod": "{int8}",
            "errorCode": "{int32}",
            "errorFoundTime": "{date}",
            "errorText": "{string}",
            "feedTime": "{date}",
            "offerURL": "{string}",
            "orderId": "{string}",
            "status": "{int8}",
            "ticketId": "{int64}",
        },
    },
    "quality_report": {
        "resource": "v2/campaigns/{campaignId}/quality/report",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/get-campaigns-id-quality-report.html",
        "key": "result",
        "extract_from_response": {
            "actualErrorCount": "{int32}",
            "ageBonus": "{float}",
            "archiveErrorCount": "{int32}",
            "checkCount": "{int32}",
            "cloneCount": "{int32}",
            "errorCount": "{int32}",
            "gradeCount": "{int32}",
            "marketRating": "{float}",
            "modificationTime": "{date}",
            "opinionCount": "{int32}",
            "opinionUrl": "{string}",
            "qualityBonus": "{float}",
            "qualityServiceRating": "{float}",
        },
    },
    "quality_ticket_fix": {
        "resource": "v2/campaigns/{campaignId}/quality/tickets/{ticketId}/fix",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-quality-tickets-id-fix.html",
        "key": "result",
    },
    "quality_check": {
        "resource": "v2/campaigns/{campaignId}/quality/check",
        "docs": "https://yandex.ru/dev/market/partner/doc/dg/reference/post-campaigns-id-quality-check.html",
        "key": "result",
        "extract_from_response": {"estimatedEndTime": "{date}", "message": "{string}"},
    },
}
